Module env

Module env 

Inspection and manipulation of the process’s environment.

This module contains functions to inspect various aspects such as process arguments, the current directory, and various other important directories.

Functions

args
Returns the arguments which this program was started with.
current_dir
Returns the current working directory as a PathBuf.
get_documents_dir
set_current_dir
Changes the current working directory to the specified path.

Type Aliases

Args