Module hw

Module hw 

Tools to interact with the hardware

This module contains functions to gather information about the calculator.

Modules

screen

Enums

Type
Returned by hw_type

Functions

clear_cache
flush the data cache and invalidate the instruction and data caches of the processor. Should be called before loading code dynamically, after a code patch or with self-modifying code.
has_colors
since Ndless v3.1. TRUE if the device has a screen in color.
has_touchpad
TRUE on a TI-Nspire Touchpad or on a TI-Nspire CX.
hw_subtype
hw_type
idle
Go to sleep until an interrupt occurs
is_classic
since Ndless v3.1. TRUE on classic TI-Nspire.
is_cm
since Ndless v3.1 r863. TRUE on TI-Nspire CM/CM-C.