pub struct SystemTimeError(/* private fields */);Expand description
An error returned from the duration_since and elapsed methods on
SystemTime, used to learn how far in the opposite direction a system time
lies.
Examples
use std::thread::sleep;
use std::time::{Duration, SystemTime};
let sys_time = SystemTime::now();
sleep(Duration::from_secs(1));
let new_sys_time = SystemTime::now();
match sys_time.duration_since(new_sys_time) {
Ok(_) => {}
Err(e) => println!("SystemTimeError difference: {:?}", e.duration()),
}Implementations
Sourceimpl SystemTimeError
impl SystemTimeError
Sourcepub fn duration(&self) -> Duration
pub fn duration(&self) -> Duration
Returns the positive duration which represents how far forward the second system time was from the first.
A SystemTimeError is returned from the duration_since and elapsed
methods of SystemTime whenever the second system time represents a point later
in time than the self of the method call.
Examples
use std::thread::sleep;
use std::time::{Duration, SystemTime};
let sys_time = SystemTime::now();
sleep(Duration::from_secs(1));
let new_sys_time = SystemTime::now();
match sys_time.duration_since(new_sys_time) {
Ok(_) => {}
Err(e) => println!("SystemTimeError difference: {:?}", e.duration()),
}Trait Implementations
Sourceimpl Clone for SystemTimeError
impl Clone for SystemTimeError
Sourcefn clone(&self) -> SystemTimeError
fn clone(&self) -> SystemTimeError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SystemTimeError
impl Debug for SystemTimeError
Sourceimpl Display for SystemTimeError
impl Display for SystemTimeError